@@ -1,12 +1,21 @@
-from indico.client import IndicoClient
+from indico.client import IndicoClient, IndicoConfig
 from indico.client.request import HTTPRequest, HTTPMethod, GraphQLRequest
 
-def test_http_request():
+def test_http_request(indico):
     client = IndicoClient()
     response = client.call(HTTPRequest(method=HTTPMethod.GET, path="/auth/users/details"))
     assert "email" in response
 
-def test_graphql_request():
+def test_disable_cookie_domain(indico):
+    client = IndicoClient(IndicoConfig(_disable_cookie_domain=True))
+    assert client.config._disable_cookie_domain == True
+    cookies = client._http.request_session.cookies
+    auth_token = next(c for c in cookies if c.name == "auth_token")
+    assert auth_token.domain == ""
+    response = client.call(HTTPRequest(method=HTTPMethod.GET, path="/auth/users/details"))
+    assert "email" in response
+
+def test_graphql_request(indico):
     client = IndicoClient()
     response = client.call(GraphQLRequest(query="""
     query {
@@ -17,8 +26,7 @@ def test_graphql_request():
         }
     }
     """))
-    assert "data" in response
-    assert "modelGroups" in response["data"]
+    assert "modelGroups" in response
 
 def test_graphql_with_ids(): 
     client = IndicoClient()
